//
//  EQLCIPCIncomingMessage.h
//  EQLibC
//
//  Created by Markus Hanauska on 08-04.
//  Copyright 2006 equinux AG. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#ifdef BUILD_EQ_LIBC_FRAMEWORK
#include "com/equinux/ipc/IPCIncomingMessage.h"
#endif

#include "EQLCIPCDataTypes.h"

@interface EQLCIPCIncomingMessage : NSObject {
#ifdef BUILD_EQ_LIBC_FRAMEWORK
	com_equinux_ipc_IncomingMessage incMessage;
#else
	void * incMessage;
#endif

}

// Just get these values
- (u_int8_t) priority;
- (u_int32_t) kind;
- (u_int32_t) sequenceNumber;
- (u_int32_t) sockedID;			// ID of socket that received this message


// Returns false if value is not found, if the native value of "parm" is of
// a different kind than "kind", it will be converted to the requested kind
// as good as possible (if possible at all).
// Primitive data types, like bool or numbers will be wrapped into NSNumber
// objects and returned.
// In case of an error, function result is "NO" and destination will be
// set to "nil".
// Even if result is "YES" destination might still be "nil" in case no
// memory for the new object could be allocated.
- (BOOL) parameter:(u_int16_t)parm ofKind:(EQLCIPCDataType)kind
	writeTo:(void **)destination;


// Returns false if value is not found, if the native value of "parm" is of
// a different kind than "kind", it will be converted to the requested kind
// as good as possible (if possible at all).
// Non-primitive data types, like NSString or NSData are not supported
// by this function, trying to access a parameter with a kind that results
// in any non-primitive object is an error for that function.
// In case of an error, function result is "NO", the value of destination
// remains unchanged.
- (BOOL) parameter:(u_int16_t)parm ofPrimitiveKind:(EQLCIPCDataType)kind
	writeTo:(void *)destination;
	

// Find out the native type of a parameter
- (EQLCIPCDataType) typeOfParamater:(u_int16_t)parm;


@end
